pub enum EntityRole {
Owned {
owner_epoch: OwnerEpoch,
},
Ghost {
owner_station: StationId,
owner_epoch: OwnerEpoch,
expires_at: Tick,
},
}Expand description
Authority role for an entity copy stored in a station.
Variants
Owned
This station is the authoritative owner.
Fields

owner_epoch: OwnerEpochOwner epoch for stale message detection.
Ghost
This station has a read-only ghost copy from an owner station.
Implementations
Sourceimpl EntityRole
impl EntityRole
Sourcepub const fn owner_epoch(self) -> OwnerEpoch
pub const fn owner_epoch(self) -> OwnerEpoch
Returns the owner epoch for ordering handoffs and stale messages.