pub struct GatewayCommandAdmission {
pub route: GatewayRoute,
pub sequence: u64,
pub commands_this_tick: usize,
}Expand description
Result of admitting a command through gateway metadata checks.
Fields
route: GatewayRouteRoute that should receive the command.
sequence: u64Accepted client-side command sequence.
commands_this_tick: usizeCommands accepted for this client in the current tick.