pub struct HandoffCommitHandles {
pub source_ghost: EntityHandle,
pub target_owner: EntityHandle,
}Expand description
Handles produced by committing a two-phase handoff.
Fields
source_ghost: EntityHandleSource station handle after it has been downgraded to a ghost.
target_owner: EntityHandleTarget station handle after it has become authoritative owner.