pub struct CellLoadSample {
pub cell: CellCoord3,
pub owned_entities: usize,
pub ghost_entities: usize,
pub subscribers: usize,
pub estimated_updates: usize,
pub estimated_bytes: usize,
pub tick_cost_units: u64,
pub event_pressure: usize,
}Expand description
Load sample for one spatial cell.
Fields
cell: CellCoord3Cell coordinate.
owned_entities: usizeOwned entity count observed in this cell.
ghost_entities: usizeGhost entity count observed in this cell.
subscribers: usizeEstimated subscribers interested in this cell.
estimated_updates: usizeEstimated updates generated by this cell for the current window.
estimated_bytes: usizeEstimated payload bytes generated by this cell for the current window.
tick_cost_units: u64Runtime-defined tick cost units for this cell.
event_pressure: usizeRuntime-defined event pressure units for this cell.
Implementations
Sourceimpl CellLoadSample
impl CellLoadSample
Sourcepub fn pressure_score(self) -> u64
pub fn pressure_score(self) -> u64
Returns a deterministic weighted pressure score for ordering cells.