pub struct HotspotThresholds {
pub max_station_entities: usize,
pub max_station_subscribers: usize,
pub max_queued_events: usize,
pub max_estimated_bytes: usize,
pub max_tick_cost_units: u64,
pub max_cell_pressure: u64,
}Expand description
Thresholds used to classify hotspot pressure.
Fields
max_station_entities: usizeMaximum total entities before a station is considered hot.
max_station_subscribers: usizeMaximum subscribers before a station is considered hot.
max_queued_events: usizeMaximum queued events before a station is considered hot.
max_estimated_bytes: usizeMaximum estimated bytes before a station is considered hot.
max_tick_cost_units: u64Maximum tick cost units before a station is considered hot.
max_cell_pressure: u64Maximum pressure score for a single cell before split is suggested.