pub struct ReplicationCadence;Expand description
Stateless distance-based replication cadence helper.
Implementations
Sourceimpl ReplicationCadence
impl ReplicationCadence
Sourcepub fn target_hz(policy: &CompiledSyncPolicy, distance_squared: f32) -> u16
pub fn target_hz(policy: &CompiledSyncPolicy, distance_squared: f32) -> u16
Returns the target update frequency for a policy at a squared distance.
Sourcepub fn interval_ticks(
policy: &CompiledSyncPolicy,
station_tick_rate_hz: u16,
distance_squared: f32,
) -> u64
pub fn interval_ticks( policy: &CompiledSyncPolicy, station_tick_rate_hz: u16, distance_squared: f32, ) -> u64
Returns the tick interval for a policy at a squared distance.
Sourcepub fn should_send(
policy: &CompiledSyncPolicy,
station_tick_rate_hz: u16,
distance_squared: f32,
now: Tick,
last_sent: Option<Tick>,
) -> bool
pub fn should_send( policy: &CompiledSyncPolicy, station_tick_rate_hz: u16, distance_squared: f32, now: Tick, last_sent: Option<Tick>, ) -> bool
Returns whether a replication update should be sent at now.