pub enum StationError {
DuplicateEntity(EntityId),
MissingEntity(EntityId),
MissingEntityHandle(EntityHandle),
NotOwner(EntityId),
AlreadyOwner(EntityId),
HandoffTargetIsSource(StationId),
WrongHandoffTarget {
expected: StationId,
actual: StationId,
},
WrongHandoffSource {
expected: StationId,
actual: StationId,
},
SnapshotStationMismatch {
expected: StationId,
actual: StationId,
},
}Expand description
Station operation error.
Variants
DuplicateEntity(EntityId)
Entity id already exists in this station.
MissingEntity(EntityId)
Entity id does not exist in this station.
MissingEntityHandle(EntityHandle)
Entity handle is missing or stale.
NotOwner(EntityId)
Operation requires an authoritative entity.
AlreadyOwner(EntityId)
This station is already authoritative for the entity.
HandoffTargetIsSource(StationId)
Handoff target cannot be the source station.
WrongHandoffTarget
Incoming transfer was addressed to a different target station.
Fields
WrongHandoffSource
Outgoing transfer was addressed from a different source station.
Fields
SnapshotStationMismatch
Snapshot was captured from a different station.