ComponentStore

Struct ComponentStore 

pub struct ComponentStore { /* private fields */ }
Station-local sparse component blob store.

Implementations

Source

impl ComponentStore

pub fn set_blob( &mut self, descriptor: &ComponentDescriptor, entity: EntityHandle, version: u64, bytes: Vec<u8>, ) -> Result<(), ComponentStoreError>

Writes an opaque component blob.

pub fn set_typed<T, C: ComponentCodec<T>>( &mut self, descriptor: &ComponentDescriptor, entity: EntityHandle, version: u64, codec: &C, value: &T, ) -> Result<(), ComponentStoreError>

Encodes and writes a typed component value using codec.

pub fn get_blob( &self, component_id: ComponentId, entity: EntityHandle, ) -> Option<&ComponentBlob>

Gets an opaque component blob.

pub fn get_typed<T, C: ComponentCodec<T>>( &self, component_id: ComponentId, entity: EntityHandle, codec: &C, ) -> Result<T, ComponentStoreError>

Decodes a typed component value using codec.

pub fn get_blob_mut( &mut self, component_id: ComponentId, entity: EntityHandle, ) -> Option<&mut ComponentBlob>

Gets a mutable opaque component blob.

pub fn clear_dirty_for_entity(&mut self, entity: EntityHandle) -> usize

Clears dirty flags for all components on one entity.

pub fn remove_entity( &mut self, entity: EntityHandle, ) -> Vec<(ComponentId, ComponentBlob)>

Removes all component blobs for an entity and returns the removed values.

pub fn copy_for_migration( &mut self, registry: &ComponentRegistry, source: EntityHandle, target: EntityHandle, ) -> usize

Copies migratable component blobs from one entity handle to another.

pub fn blob_count(&self) -> usize

Returns number of component blobs stored in all columns.