pub struct SplitProposal {
pub source_station: StationId,
pub cells_to_move: Vec<CellCoord3>,
pub moved_pressure_score: u64,
}Expand description
Cell split proposal for external schedulers.
Fields
source_station: StationIdSource station that should give up some cell ownership.
cells_to_move: Vec<CellCoord3>Cells recommended for movement to a new or less loaded station.
moved_pressure_score: u64Total pressure score covered by cells_to_move.